@@ -85,7 +85,6 @@ Projection.getCadToolBarPanel = function() {
         action.setScriptFile(Projection.includeBasePath + "/Projection.js");
         action.objectName = actionName;
         action.setRequiresDocument(true);
-        action.setIcon(Projection.includeBasePath + "/Projection.svg");
         //action.setStatusTip(qsTr("Show projection tools"));
         action.setDefaultShortcut(new QKeySequence("w,j"));
         action.setNoState();
@@ -243,31 +242,46 @@ Projection.prototype.transform = function(entity, k, op, preview, flags, rec) {
         this.preTransform(entity);
     }
 
+    var explode = false;
+
     if (this.retainTexts && isTextBasedEntity(entity)) {
-        // don't explode text, only project position:
-        var e = entity.clone();
-        e.setSelected(false);
-        var p = e.getAlignmentPoint();
-        var ph = p.operator_add(new RVector(0,e.getTextHeight()));
-        //qDebug("p before:", p);
-        //qDebug("ap:", e.getAlignmentPoint());
-        this.project(p);
-        this.project(ph);
+        if (isAttributeEntity(entity)) {
+            explode = true;
+        }
+        else {
+            // don't explode text, only project position:
+            var e = entity.clone();
+            e.setSelected(false);
+            var p = e.getAlignmentPoint();
+            var ph = p.operator_add(new RVector(0,e.getTextHeight()));
+            //qDebug("p before:", p);
+            //qDebug("ph before:", ph);
+            //qDebug("ap:", e.getAlignmentPoint());
+            this.project(p);
+            this.project(ph);
 
-        // project height:
-        //qDebug("p after:", p);
-        //e.setPosition(p);
+            // project height:
+            //qDebug("p after:", p);
+            //qDebug("ph after:", ph);
+            //e.setPosition(p);
 
-        e.setAlignmentPoint(p);
-        e.setTextHeight(p.getDistanceTo(ph));
+            e.setAlignmentPoint(p);
+            e.setTextHeight(p.getDistanceTo(ph));
 
-        flags = flags | RAddObjectsOperation.UseAttributes;
-        op.addObject(e, flags);
-        return;
+            flags = flags | RAddObjectsOperation.UseAttributes;
+            op.addObject(e, flags);
+            return;
+        }
     }
 
     // explode block reference to keep attributes (colors, etc.):
     if (isBlockReferenceEntity(entity)) {
+        explode = true;
+    }
+
+    if (explode) {
+        // explode attributes to texts
+        // explode block reference
         var explodedEntities = Explode.explodeEntity(entity);
         if (!isNull(explodedEntities)) {
             for (i=0; i<explodedEntities.length; i++) {
@@ -318,7 +332,7 @@ Projection.prototype.addTransformedShapes = function(entity, shapes, op, preview
         hd.newLoop();
 
         for (i=0; i<shapes.length; i++) {
-            s = this.projectShape(shapes[i].data(), preview);
+            s = this.projectShape(getPtr(shapes[i]), preview);
             for (n=0; n<s.length; n++) {
                 if (isNull(s[n])) {
                     debugger;
@@ -328,7 +342,12 @@ Projection.prototype.addTransformedShapes = function(entity, shapes, op, preview
                     s[n].simplify(0.001);
                 }
 
-                hd.addBoundary(s[n], true);
+                if (RSettings.getQtVersion() >= 0x060000) {
+                    hd.addBoundary(s[n].clone(), true);
+                }
+                else {
+                    hd.addBoundary(s[n], true);
+                }
             }
         }
 
@@ -353,7 +372,7 @@ Projection.prototype.addTransformedShapes = function(entity, shapes, op, preview
             continue;
         }
 
-        s = this.projectShape(shapes[i].data(), preview);
+        s = this.projectShape(getPtr(shapes[i]), preview);
         for (n=0; n<s.length; n++) {
             if (isNull(s[n])) {
                 debugger;
@@ -364,7 +383,7 @@ Projection.prototype.addTransformedShapes = function(entity, shapes, op, preview
                 continue;
             }
 
-            e.copyAttributesFrom(entity);
+            e.copyAttributesFrom(getPtr(entity));
             //e.move(this.targetPoint);
             flags = flags | RAddObjectsOperation.UseAttributes;
             op.addObject(e, flags);
@@ -545,6 +564,8 @@ Projection.prototype.projectShape = function(shape, preview, trim, rec) {
         // create polyline from ellipse:
         var ple = ShapeAlgorithms.approximateEllipse(shape, 16);
         return this.projectShape(ple, preview, trim);
+
+        // TODO: project ellipse bounding box and inscribe new ellipse (?)
     }
 
     if (isTriangleShape(shape)) {
@@ -570,7 +591,7 @@ Projection.prototype.projectShape = function(shape, preview, trim, rec) {
 //        var shapes = shape.getExploded(segments);
 //        var pls = new RPolyline();
 //        for (i=0; i<shapes.length; i++) {
-//            s = shapes[i].data();
+//            s = getPtr(shapes[i]);
 //            pls.appendShape(s);
 //        }
         ret = this.projectShape(pls, preview, trim);
@@ -593,7 +614,7 @@ Projection.prototype.projectShape = function(shape, preview, trim, rec) {
 
         // project each segment individually:
         for (i=0; i<segmentCount; i++) {
-            s = shape.getSegmentAt(i).data();
+            s = getPtr(shape.getSegmentAt(i));
 
             s = this.projectShape(s, preview, trim, true);
 
@@ -601,7 +622,7 @@ Projection.prototype.projectShape = function(shape, preview, trim, rec) {
             for (k=0; k<s.length; k++) {
                 var seg = s[k];
                 if (isFunction(seg.data)) {
-                    seg = seg.data();
+                    seg = getPtr(seg);
                 }
 
                 var gotGap = pl.countVertices()>0 &&
@@ -610,7 +631,7 @@ Projection.prototype.projectShape = function(shape, preview, trim, rec) {
                 // s is a line or polyline that connets to the polyline we have:
                 if (!gotGap && (isLineShape(seg) || isPolylineShape(seg))) {
                     if (seg.getLength()>RS.PointTolerance) {
-                        pl.appendShape(seg);
+                        pl.appendShape(getPtr(seg));
                     }
                 }
 
@@ -638,7 +659,7 @@ Projection.prototype.projectShape = function(shape, preview, trim, rec) {
                     else if (gotGap){
                         pl = new RPolyline();
                         //qDebug("seg:", seg);
-                        pl.appendShape(seg);
+                        pl.appendShape(getPtr(seg));
                         addPl = true;
                     }
                 }
