@@ -52,11 +52,13 @@ function RBlockListQt(parent, addListener, showHeader) {
         this.header().setSectionResizeMode(BlockList.colName, QHeaderView.Stretch);
         this.header().setSectionResizeMode(BlockList.colVisible, QHeaderView.Interactive);
         this.header().setSectionResizeMode(BlockList.colEdit, QHeaderView.Interactive);
+        //this.header().setSectionResizeMode(BlockList.colXRef, QHeaderView.Interactive);
     }
     else {
         this.header().setResizeMode(BlockList.colName, QHeaderView.Stretch);
         this.header().setResizeMode(BlockList.colVisible, QHeaderView.Interactive);
         this.header().setResizeMode(BlockList.colEdit, QHeaderView.Interactive);
+        //this.header().setResizeMode(BlockList.colXRef, QHeaderView.Interactive);
     }
 
     // Qt 6.6.1 workaround: this only works once widget is visible:
@@ -69,6 +71,7 @@ function RBlockListQt(parent, addListener, showHeader) {
         var adapter = new RBlockListenerAdapter();
         appWin.addBlockListener(adapter);
         adapter.blocksUpdated.connect(function(di) { self.updateBlocks(di); });
+        adapter.xRefUpdated.connect(function() { self.updateXRef(); });
         adapter.currentBlockSet.connect(function(di) { self.updateCurrentBlock(di); });
         adapter.blocksCleared.connect(function() { self.clearBlocks(); });
     }
@@ -94,15 +97,18 @@ RBlockListQt.getWidget = function() {
  * Add an additional action to be used in the context menu.
  * Can be used by plugins to hook into the block list context menu.
  */
-RBlockListQt.addContextMenuScriptFile = function(scriptFile, blockList) {
+RBlockListQt.addContextMenuScriptFile = function(scriptFile, blockList, xRefOnly) {
     //var blockList = RBlockListQt.getWidget();
     if (isNull(blockList)) {
         return;
     }
 
     var scriptFiles = RBlockListQt.getContextMenuScriptFiles(blockList);
+    var scriptFileXRefOnly = RBlockListQt.getContextMenuScriptFileXRefOnly(blockList);
     scriptFiles.push(scriptFile);
+    scriptFileXRefOnly.push(xRefOnly.toString());
     blockList.setProperty("ContextMenuScriptFiles", scriptFiles);
+    blockList.setProperty("ContextMenuScriptFileXRefOnly", scriptFileXRefOnly);
 };
 
 RBlockListQt.getContextMenuScriptFiles = function(blockList) {
@@ -118,12 +124,33 @@ RBlockListQt.getContextMenuScriptFiles = function(blockList) {
     return scriptFiles;
 };
 
+RBlockListQt.getContextMenuScriptFileXRefOnly = function(blockList) {
+    //var blockList = RBlockListQt.getWidget();
+    if (isNull(blockList)) {
+        return [];
+    }
+
+    var scriptFileXRefOnly = blockList.property("ContextMenuScriptFileXRefOnly");
+    if (isNull(scriptFileXRefOnly)) {
+        scriptFileXRefOnly = [];
+    }
+    return scriptFileXRefOnly;
+};
+
 RBlockListQt.prototype.contextMenuEvent = function(e) {
     var item = this.itemAt(e.pos());
     if (!isNull(item)) {
         this.setCurrentItem(item);
     }
 
+    var document = this.di.getDocument();
+    var blockName = this.getBlockName(item);
+    var block = document.queryBlockDirect(blockName);
+    var isXRef = false;
+    if (!isNull(block)) {
+        isXRef = block.isXRef();
+    }
+
     var menu = new QMenu();
 
     RGuiAction.getByScriptFile("scripts/Block/ToggleBlockVisibility/ToggleBlockVisibility.js").addToMenu(menu);
@@ -137,18 +164,30 @@ RBlockListQt.prototype.contextMenuEvent = function(e) {
     RGuiAction.getByScriptFile("scripts/Block/SelectBlockReferences/SelectBlockReferences.js").addToMenu(menu);
     RGuiAction.getByScriptFile("scripts/Block/DeselectBlockReferences/DeselectBlockReferences.js").addToMenu(menu);
 
-    RBlockListQt.complementContextMenu(menu, RBlockListQt.getWidget());
+    RBlockListQt.complementContextMenu(menu, RBlockListQt.getWidget(), isXRef);
 
     menu.exec(QCursor.pos());
 
     e.ignore();
 };
 
-RBlockListQt.complementContextMenu = function(menu, blockListWidget) {
+RBlockListQt.complementContextMenu = function(menu, blockListWidget, isXRef) {
+    if (isNull(isXRef)) {
+        isXRef = false;
+    }
+
     // add additional context menu actions provided by plugins:
     var scriptFiles = RBlockListQt.getContextMenuScriptFiles(blockListWidget);
-    for (var i=0; i<scriptFiles.length; i++) {
+    var scriptFileXRefOnly = RBlockListQt.getContextMenuScriptFileXRefOnly(blockListWidget);
+    for (var i=0; i<scriptFiles.length && i<scriptFileXRefOnly.length; i++) {
         var scriptFile = scriptFiles[i];
+        var xRefOnly = scriptFileXRefOnly[i]==="1";
+
+        if (xRefOnly && !isXRef) {
+            // menu not applicable for non-XRef blocks:
+            continue;
+        }
+
         var a = RGuiAction.getByScriptFile(scriptFile);
         if (!isNull(a)) {
             a.addToMenu(menu);
@@ -202,6 +241,40 @@ RBlockListQt.prototype.updateCurrentBlock = function(documentInterface) {
     }
 };
 
+/**
+ * Called when the XRef status of the current block changes. Updates the XRef icon.
+ */
+RBlockListQt.prototype.updateXRef = function() {
+    if (isNull(this.di)) {
+        return;
+    }
+
+    var doc = this.di.getDocument();
+
+    // find item of current block:
+    var item = RBlockListQt.getItem(this, doc.getCurrentBlockName());
+
+    // update XRef icon for item:
+    if (!isNull(item)) {
+        var block = doc.queryCurrentBlock();
+        var isXRef = false;
+        var isFromXRef = false;
+        if (!isNull(block)) {
+            // block is XRef:
+            isXRef = block.isXRef();
+            // block is a block that lives inside an XRef:s
+            isFromXRef = block.isFromXRef();
+        }
+
+        if (isXRef) {
+            item.setIcon(BlockList.colEdit, BlockList.iconXRef[Number(isXRef)]);
+        }
+        else if (isFromXRef) {
+            item.setIcon(BlockList.colEdit, BlockList.iconFromXRef[Number(isFromXRef)]);
+        }
+    }
+};
+
 /**
  * Called when blocks are added, edited or deleted. Updates the block list.
  */
@@ -311,13 +384,24 @@ RBlockListQt.prototype.createBlockItem = function(block) {
 };
 
 RBlockListQt.prototype.updateItemIcons = function(item, block) {
-    //var iconName = autoIconPath(BlockList.includeBasePath + "/Visible%1.svg".arg(Number(!block.isFrozen())));
     item.setIcon(BlockList.colVisible, BlockList.iconVisible[Number(!block.isFrozen())]);
 
     var doc = this.di.getDocument();
     var currentBlockId = doc.getCurrentBlockId();
-    //iconName = autoIconPath(BlockList.includeBasePath + "/Edit%1.svg".arg(Number(block.getId()===currentBlockId)));
-    item.setIcon(BlockList.colEdit, BlockList.iconEdit[Number(block.getId()===currentBlockId)]);
+
+    // set icon to XRef icon (not editable) or edit icon for regular blocks:
+    if (block.isXRef()) {
+        item.setIcon(BlockList.colEdit, BlockList.iconXRef[1]);
+    }
+    else if (block.isFromXRef()) {
+        item.setIcon(BlockList.colEdit, BlockList.iconFromXRef[1]);
+    }
+    else {
+        item.setIcon(BlockList.colEdit, BlockList.iconEdit[Number(block.getId()===currentBlockId)]);
+    }
+
+
+    //item.setIcon(BlockList.colEdit, BlockList.iconXRef[Number(block.isXRef())]);
 };
 
 /**
@@ -351,7 +435,9 @@ RBlockListQt.prototype.itemColumnClickedSlot = function(item, column) {
         this.setCurrentItem(item);
         this.editBlock();
         //this.updateBlocks(this.di);
-    }
+    } /*else if (column===BlockList.colXRef) {
+        this.setCurrentItem(item);
+    }*/
 
     this.blockActivated();
 };
@@ -371,12 +457,6 @@ RBlockListQt.prototype.blockActivated = function() {
         return;
     }
 
-    var item = list[0];
-    if (isNull(item)) {
-        this.enableActions(false);
-        return;
-    }
-
     var document = this.di.getDocument();
     if (isNull(document)) {
         this.enableActions(false);
@@ -389,12 +469,29 @@ RBlockListQt.prototype.blockActivated = function() {
         return;
     }
 
-    var blockName = this.getBlockName(item);
+    var insertable = true;
+    var renamable = true;
+    var removable = true;
+    for (var i=0; i<list.length; i++) {
+        var item = list[i];
+
+        if (isNull(item)) {
+            continue;
+        }
+
+        var blockName = this.getBlockName(item);
+        var block = document.queryBlockDirect(blockName);
+        if (isNull(block)) {
+            continue;
+        }
+
+        insertable = insertable && currentBlock.getName().toLowerCase()!==blockName.toLowerCase() && !blockName.startsWith("*");
+        renamable = renamable && document.getBlockId(blockName)!==document.getModelSpaceBlockId() && !block.isFromXRef();
+        removable = removable && document.getBlockId(blockName)!==document.getModelSpaceBlockId() && !block.isFromXRef();
+        // cannot remove block from XRef:
+        removable = removable && !block.isFromXRef();
+    }
 
-    // prevent removal or insertion of current block:
-    var insertable = currentBlock.getName().toLowerCase()!==blockName.toLowerCase() && !blockName.startsWith("*");
-    var renamable = document.getBlockId(blockName)!==document.getModelSpaceBlockId();
-    var removable = document.getBlockId(blockName)!==document.getModelSpaceBlockId();
     this.enableActions(insertable, renamable, removable);
 };
 
@@ -455,7 +552,21 @@ RBlockListQt.prototype.enableActions = function(insertable, renamable, removable
  * (double click).
  */
 RBlockListQt.prototype.editBlock = function() {
-    var action = RGuiAction.getByScriptFile("scripts/Block/EditBlock/EditBlock.js");
+    var block = this.getSelectedBlock();
+
+    var action = undefined;
+
+    if (!isNull(block) && block.isXRef() && !block.isFromXRef()) {
+        // one single block selected in block list:
+
+        // editing XRef triggers rename which also allows editing the path:
+        action = RGuiAction.getByScriptFile("scripts/Block/RenameBlock/RenameBlock.js");
+    }
+
+    if (isNull(action)) {
+        action = RGuiAction.getByScriptFile("scripts/Block/EditBlock/EditBlock.js");
+    }
+
     if (!isNull(action)) {
         action.slotTrigger();
     }
@@ -463,6 +574,21 @@ RBlockListQt.prototype.editBlock = function() {
     this.blockActivated();
 };
 
+/**
+ * If one item is selected, return the corresponding block otherwise undefined.
+ */
+RBlockListQt.prototype.getSelectedBlock = function() {
+    var items = BlockList.getSelectedItems();
+    if (items.length===1) {
+        // one single block selected in block list:
+        var item = items[0];
+        var blockName = this.getBlockName(item);
+        var doc = this.di.getDocument();
+        return doc.queryBlockDirect(blockName);
+    }
+    return undefined;
+};
+
 
 
 /**
@@ -483,6 +609,8 @@ BlockList.colName=2;
 
 BlockList.iconVisible = [];
 BlockList.iconEdit = [];
+BlockList.iconXRef = [];
+BlockList.iconFromXRef = [];
 
 BlockList.initStyle = function(upd) {
     if (isNull(upd)) {
@@ -496,7 +624,18 @@ BlockList.initStyle = function(upd) {
 
     BlockList.iconEdit = [
         new QIcon(autoIconPath(BlockList.includeBasePath + "/Edit0.svg")),
-        new QIcon(autoIconPath(BlockList.includeBasePath + "/Edit1.svg"))
+        new QIcon(autoIconPath(BlockList.includeBasePath + "/Edit1.svg")),
+        new QIcon(autoIconPath(BlockList.includeBasePath + "/Edit2.svg"))
+    ];
+
+    BlockList.iconXRef = [
+        new QIcon(autoIconPath(BlockList.includeBasePath + "/XRef0.svg")),
+        new QIcon(autoIconPath(BlockList.includeBasePath + "/XRef1.svg"))
+    ];
+
+    BlockList.iconFromXRef = [
+        new QIcon(autoIconPath(BlockList.includeBasePath + "/FromXRef0.svg")),
+        new QIcon(autoIconPath(BlockList.includeBasePath + "/FromXRef1.svg"))
     ];
 
     if (upd) {
@@ -565,6 +704,7 @@ BlockList.prototype.finishEvent = function() {
 };
 
 BlockList.initColumnWidths = function(blockList) {
+    //blockList.setColumnWidth(BlockList.colXRef, 22);
     blockList.setColumnWidth(BlockList.colVisible, 22);
     blockList.setColumnWidth(BlockList.colEdit, 22);
 };
