@@ -165,7 +165,7 @@ function destrDialog(dlg) {
  * Get pointer from shared pointer object using data() (Qt5) or implicitly (Qt6).
  */
 function getPtr(p) {
-    if (RSettings.getQtVersion() > 0x060000) {
+    if (RSettings.getQtVersion() >= 0x060000) {
         return p;
     }
     else {
@@ -189,8 +189,17 @@ function isNull(obj) {
         return true;
     }
 
+    if (obj==null) {
+        return true;
+    }
+
+    if (RSettings.getQtVersion() >= 0x060000) {
+        if (obj.hasOwnProperty("__PROXY__")) {
+            return isNull(obj.__PROXY__);
+        }
+    }
+
     return (
-        obj==null ||
         // wrapped object is NULL:
         (typeof(obj.isNullWrapper)==="function" && obj.isNullWrapper()===true) ||
         // shared pointer is NULL:
@@ -1383,7 +1392,15 @@ function entityTypeToString(type, plural) {
     case RS.EntityXRef:
         return plural ? qsTr("External References") : qsTr("External Reference");
     case RS.EntityUnknown:
+        return plural ? qsTr("Unknown Entities") : qsTr("Unknown Entity");
     default:
+        if (type>=RS.EntityCustom && type<RS.EntityUser) {
+            var handler = RCustomEntityRegistry.getHandler(type);
+            if (!isNull(handler)) {
+                var name = handler.getEntityName(plural);
+                return qsTranslate("RCustomEntity", name);
+            }
+        }
         return plural ? qsTr("Unknown Entities") : qsTr("Unknown Entity");
     }
 }
@@ -2573,10 +2590,7 @@ function shapeToEntity(document, shape) {
         return undefined;
     }
 
-    var s = shape;
-    if (isFunction(s.data)) {
-        s = s.data();
-    }
+    var s = getPtr(shape);
 
     switch (s.getShapeType()) {
     case RShape.Point:
@@ -2657,21 +2671,15 @@ function modifyEntity(op, entity, shape) {
         (isCircleEntity(entity) && isArcShape(shape))) {
 
         var e = shapeToEntity(entity.getDocument(), shape);
-//        if (isFunction(entity.data)) {
-//            e.copyAttributesFrom(entity.data());
-//            op.deleteObject(entity.data());
-//        }
-//        else {
-            e.copyAttributesFrom(entity);
-            op.deleteObject(entity);
-//        }
+        e.copyAttributesFrom(getPtr(entity));
+        op.deleteObject(entity);
 
         op.addObject(e, false);
         return true;
     }
 
     if (isFunction(entity.setShape)) {
-        entity.setShape(shape);
+        entity.setShape(getPtr(shape));
         op.addObject(entity, false);
         return true;
     }
@@ -2869,22 +2877,15 @@ function initUserShortcuts() {
             continue;
         }
 
-        var match = action.getScriptFile().contains("OpenFile");
-
         var scStringList = RSettings.getValue("Shortcuts/" + key);
 
-        if (match) qDebug("scStringList", scStringList);
-
         // explicitly no shortcuts:
         if (isNull(scStringList)) {
-            if (match) qDebug("explicitly no shortcuts");
             action.setShortcuts([]);
             action.removeShortcuts();
             continue;
         }
 
-        if (match) qDebug("setting shortcuts to ", scStringList);
-
         //action.setShortcutsFromStrings(scStringList);
         //action.setShortcuts(scStringList);
 
@@ -3051,8 +3052,12 @@ function isUrl(urlString) {
 }
 
 function getDontUseNativeDialog() {
-    // don't use KDE file dialog (workaround for file type filter bug):
-    return RS.getWindowManagerId()==="kde" || RSettings.getBoolValue("SaveAs/UseSystemFileDialog", true)===false;
+    if (RS.getWindowManagerId()==="kde") {
+        // don't use KDE file dialog (workaround for file type filter bug):
+        return true;
+    }
+
+    return RSettings.getBoolValue("SaveAs/UseSystemFileDialog", true)===false;
 };
 
 function autoPath(path) {
@@ -3124,7 +3129,7 @@ function autoIconPath(path) {
 
     if (!new QFileInfo(path).exists()) {
         // given icon does not exist (for icons based on object names, e.g. in options toolbar):
-        return undefined;
+        return "";
     }
 
     return path;
