@@ -243,7 +243,7 @@
         <translation>Блок</translation>
     </message>
     <message>
-        <location filename="../src/core/RBlockReferenceEntity.cpp" line="+99"/>
+        <location filename="../src/core/RBlockReferenceEntity.cpp" line="+102"/>
         <location line="+1"/>
         <location line="+1"/>
         <location filename="../src/core/RViewportEntity.cpp" line="+80"/>
@@ -253,7 +253,7 @@
         <translation>Положение</translation>
     </message>
     <message>
-        <location filename="../src/core/RBlock.cpp" line="+69"/>
+        <location filename="../src/core/RBlock.cpp" line="+75"/>
         <source>Pixel Unit</source>
         <translation>Единицы измерения точек</translation>
     </message>
@@ -319,13 +319,23 @@
     <message>
         <location line="+1"/>
         <source>Owned by Reference</source>
-        <translation type="unfinished">Принадлежит справочнику</translation>
+        <translation>Принадлежит справочнику</translation>
     </message>
     <message>
-        <location filename="../src/core/RBlockReferenceEntity.cpp" line="-6"/>
+        <location line="+1"/>
+        <source>External reference</source>
+        <translation>Внешняя ссылка</translation>
+    </message>
+    <message>
+        <location filename="../src/core/RBlockReferenceEntity.cpp" line="-7"/>
         <source>Referenced Block</source>
         <translation>Блок, на который дана ссылка</translation>
     </message>
+    <message>
+        <location line="+1"/>
+        <source>External Reference</source>
+        <translation>Внешняя ссылка</translation>
+    </message>
     <message>
         <location line="+4"/>
         <location line="+1"/>
@@ -615,15 +625,15 @@
     <message>
         <location line="+2"/>
         <source>Frozen Layers</source>
-        <translation type="unfinished">Замороженные слои</translation>
+        <translation>Замороженные слои</translation>
     </message>
     <message>
         <location line="+0"/>
         <source>Layer ID</source>
-        <translation type="unfinished">Идентификатор слоя</translation>
+        <translation>Идентификатор слоя</translation>
     </message>
     <message>
-        <location filename="../src/core/RBlock.cpp" line="-7"/>
+        <location filename="../src/core/RBlock.cpp" line="-8"/>
         <location filename="../src/core/RLayer.cpp" line="-8"/>
         <location filename="../src/core/RLayerState.cpp" line="+46"/>
         <location filename="../src/core/RLayout.cpp" line="-24"/>
@@ -711,7 +721,7 @@
         <translation>Максимальные степени</translation>
     </message>
     <message>
-        <location filename="../src/core/RBlockReferenceData.cpp" line="+886"/>
+        <location filename="../src/core/RBlockReferenceData.cpp" line="+920"/>
         <source>Circular (recursive) block referencing detected:</source>
         <translation>Обнаружена круговая (рекурсивная) ссылка на блок:</translation>
     </message>
@@ -1055,10 +1065,25 @@
         <source>Fenceline 2</source>
         <translation>Линия ограждения 2</translation>
     </message>
+    <message>
+        <location line="+1"/>
+        <source>Point 1</source>
+        <translation>Точка 1</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>Point 2</source>
+        <translation>Точка 2</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>Plant</source>
+        <translation>Установка</translation>
+    </message>
     <message>
         <location line="+2"/>
         <source>Water</source>
-        <translation type="unfinished">Вода</translation>
+        <translation>Вода</translation>
     </message>
     <message>
         <location line="+1"/>
@@ -1073,37 +1098,37 @@
     <message>
         <location line="+2"/>
         <source>Communication</source>
-        <translation type="unfinished">Общение</translation>
+        <translation>Общение</translation>
     </message>
     <message>
         <location line="+1"/>
         <source>Electric</source>
-        <translation type="unfinished">Электрический</translation>
+        <translation>Электрический</translation>
     </message>
     <message>
         <location line="+1"/>
         <source>Low Voltage</source>
-        <translation type="unfinished">Низкое напряжение</translation>
+        <translation>Низкое напряжение</translation>
     </message>
     <message>
         <location line="+1"/>
         <source>High Voltage</source>
-        <translation type="unfinished">Высокое напряжение</translation>
+        <translation>Высокое напряжение</translation>
     </message>
     <message>
         <location line="+1"/>
         <source>Overhead Power</source>
-        <translation type="unfinished">Накладная мощность</translation>
+        <translation>Накладная мощность</translation>
     </message>
     <message>
         <location line="+2"/>
         <source>Foul</source>
-        <translation type="unfinished">Foul</translation>
+        <translation>Foul</translation>
     </message>
     <message>
         <location line="+1"/>
         <source>Foul Rising</source>
-        <translation type="unfinished">Восстание фолов</translation>
+        <translation>Восстание фолов</translation>
     </message>
 </context>
 <context>
